import enum

class Auto_Mode(enum.Enum):
    disable: int
    normal: int
    high: int
    highest: int

def isEntryPoint(): ...
def get_real_exe_dir() -> str: ...
def get_temp_path(relative_path: str = ...): ...
def print_file_tree(path) -> None: ...
def is_nuitka_packaged() -> bool: ...
def is_pyinstaller_packaged() -> bool: ...
def copy_file_to(becopyed_file_path: str, new_file_path: str, cover: bool = ..., file_name: str = ...): ...
def getProjectPath(layer: int = ..., auto: Auto_Mode = ...) -> str: ...
